@@ -1,12 +1,28 @@
 from __future__ import absolute_import
 
-import json
 import sys
-import pprint
 import os
+if sys.platform == "darwin":
+    import matplotlib
+    matplotlib.use("TkAgg")
+elif 'DISPLAY' not in os.environ:
+    import matplotlib
+    matplotlib.use("Agg")
+
+try:
+    import tkinter
+except ImportError as e:
+    import matplotlib
+    matplotlib.use("agg")
+    import matplotlib.pyplot as plt
+else:
+    import matplotlib.pyplot as plt
+
+
+import json
+import pprint
 import re
 import numpy as np
-import matplotlib.pyplot as plt
 import yaml
 from future.utils import iteritems
 import pandas as pd
@@ -18,8 +34,6 @@ from scope_plot import schema
 from scope_plot.benchmark import GoogleBenchmark
 from scope_plot import styles
 
-# plt.switch_backend('agg')
-
 
 def configure_yaxis(ax, axis_spec):
     if "lim" in axis_spec:
@@ -73,9 +87,15 @@ def generator_bar(ax, ax_cfg):
             utils.debug("series {}: yscale: {}".format(i, y_scale))
 
         with GoogleBenchmark(input_path) as b:
-            series_df = b.keep_name_regex(regex).xy_dataframe(x_field, y_field)
+            matches = b.keep_name_regex(regex)
+            for entry in matches.benchmarks:
+                utils.debug("name {} matched regex {}".format(entry["name"], regex))
+            series_df = matches.xy_dataframe(x_field, y_field)
 
-        series_df.loc[:, x_field] *= x_scale
+        if series_df.dtypes[x_field] == np.object:
+            utils.debug("Not scaling non-numeric x data by {}".format(x_scale))
+        else:
+            series_df.loc[:, x_field] *= x_scale
         series_df.loc[:, y_field] *= y_scale
         series_df = series_df.rename(columns={y_field: label})
         series_df = series_df.set_index(x_field)
@@ -83,8 +103,8 @@ def generator_bar(ax, ax_cfg):
         # FIXME: this could be resolved with join?
         # https://stackoverflow.com/questions/27719407/pandas-concat-valueerror-shape-of-passed-values-is-blah-indices-imply-blah2
         if not series_df.index.is_unique:
-            utils.error(
-                "multiple benchmark results with equal x_field={} values. The plot might be weird.".format(
+            utils.warn(
+                "multiple benchmark results with identical {} values. The plot might be weird.".format(
                     x_field))
         df = pd.concat([df, series_df], axis=1, sort=False)
     df = df.sort_index()
@@ -109,12 +129,14 @@ def generator_errorbar(ax, ax_cfg):
 
     for i, series_spec in enumerate(series_specs):
         file_path = series_spec.input_file()
-        label = series_spec.label_or(str(i))
+        label = series_spec.label_or(None)
         regex = series_spec.regex()
         yscale = series_spec.yscale()
         xscale = series_spec.xscale()
         x_field = series_spec.xfield()
         y_field = series_spec.yfield()
+        linestyle = series_spec.linestyle()
+        utils.debug("series {}: linestyle: {}".format(i, linestyle))
         utils.debug("series {}: opening {}".format(i, file_path))
 
         with GoogleBenchmark(file_path) as g:
@@ -128,9 +150,10 @@ def generator_errorbar(ax, ax_cfg):
         x *= xscale
         y *= yscale
         e *= yscale
-
+        alpha = series_spec.alpha()
         color = series_spec.color_or(styles.colors[i])
-        ax.errorbar(x, y, e, capsize=3, label=label, color=color)
+        utils.debug("series {}: color = {} alpha = {}".format(i, color, alpha))
+        ax.errorbar(x, y, e, capsize=3, label=label, color=color, linestyle=linestyle)
 
     if "title" in ax_cfg:
         ax.set_title(ax_cfg["title"])
