@@ -30,6 +30,8 @@ COLOR = Any(basestring, float, int)
 EVAL = Any(basestring, float, int)
 
 SERIES_SCHEMA = Schema({
+    Optional("alpha"): float,
+    Optional("color"): COLOR,
     Optional("label"): basestring,
     Optional("input_file"): basestring,
     Optional("regex"): basestring,
@@ -37,9 +39,9 @@ SERIES_SCHEMA = Schema({
     Optional("yfield"): basestring,
     Optional("xscale"): EVAL,
     Optional("yscale"): EVAL,
-    Optional("color"): COLOR,
     Optional("tick_seperator"): basestring,
     Optional("tick_fields"): list,
+    Optional("linestyle"): basestring,
 })
 
 POS = list
@@ -79,7 +81,11 @@ BAR_EXTENSIONS = {
 }
 BAR_FIELDS = PLOT_FIELDS.extend(BAR_EXTENSIONS)
 
-ERRORBAR_EXTENSIONS = {}
+ERRORBAR_EXTENSIONS = {
+    Optional("alpha"): float,
+    Optional("linestyle"): basestring,
+    Optional("color"): COLOR,
+}
 ERRORBAR_FIELDS = PLOT_FIELDS.extend(ERRORBAR_EXTENSIONS)
 
 REG_EXTENSIONS = {
@@ -129,11 +135,11 @@ BAR_FIGURE = BAR_FIGURE_FIELDS
 ERRORBAR_FIGURE = ERRORBAR_FIGURE_FIELDS
 REG_FIGURE = REG_FIGURE_FIELDS
 
-# an errorbar plot in a subplot
-ERRORBAR_SUBPLOT = SUBPLOT_FIELDS
+# an errorbar plot in a subplot is a subplot and an errorbar plot
+ERRORBAR_SUBPLOT = SUBPLOT_FIELDS.extend(ERRORBAR_EXTENSIONS)
 BAR_SUBPLOT = BAR_SUBPLOT_FIELDS
 
-# anythink that can be a subplot
+# anything that can be a subplot
 SUBPLOT = Any(
     ERRORBAR_SUBPLOT,
     BAR_SUBPLOT,
