@@ -9,14 +9,19 @@ THIS_DIR = os.path.dirname(os.path.realpath(__file__))
 def generate_html(name):
     figure_spec = Specification.load_yaml(os.path.join(THIS_DIR, name))
     figure_spec.find_input_files([THIS_DIR])
-    jobs = backend.construct_jobs(figure_spec, ["test.html"])
+    path = "test.html"
+    backend_str = backend.infer_from_path(path)
+    jobs = backend.construct_jobs(figure_spec, [(path, backend_str)])
     for job in jobs:
         backend.run(job)
 
+
 def generate_pdf(name):
     figure_spec = Specification.load_yaml(os.path.join(THIS_DIR, name))
     figure_spec.find_input_files([THIS_DIR])
-    jobs = backend.construct_jobs(figure_spec, ["test.pdf"])
+    path = "test.pdf"
+    backend_str = backend.infer_from_path(path)
+    jobs = backend.construct_jobs(figure_spec, [(path, backend_str)])
     for job in jobs:
         backend.run(job)
 
