@@ -10,7 +10,9 @@ FIXTURES_DIR = os.path.join(
 def generate_fixture(name):
     figure_spec = Specification.load_yaml(os.path.join(FIXTURES_DIR, name))
     figure_spec.find_input_files([FIXTURES_DIR])
-    jobs = backend.construct_jobs(figure_spec, ["test.pdf"])
+    path = "test.pdf"
+    backend_str = backend.infer_from_path(path)
+    jobs = backend.construct_jobs(figure_spec, [(path, backend_str)])
     for job in jobs:
         backend.run(job)
 
